@@ -9,25 +9,30 @@ from elementary.monitor.data_monitoring.data_monitoring_alerts import (
 from elementary.monitor.data_monitoring.report.data_monitoring_report import (
     DataMonitoringReport,
 )
-from elementary.tracking.anonymous_tracking import AnonymousTracking
+from elementary.monitor.debug import Debug
+from elementary.tracking.anonymous_tracking import AnonymousCommandLineTracking
 from elementary.utils import bucket_path
-from elementary.utils.log import get_logger
 from elementary.utils.ordered_yaml import OrderedYaml
 
 yaml = OrderedYaml()
 
-logger = get_logger(__name__)
-
 
 class Command:
     MONITOR = "monitor"
     REPORT = "monitor-report"
     SEND_REPORT = "monitor-send-report"
+    DEBUG = "debug"
 
 
 # Displayed in reverse order in --help.
 def common_options(cmd: str):
     def decorator(func):
+        func = click.option(
+            "--target-path",
+            type=str,
+            default=Config.DEFAULT_FILES_PATH,
+            help="Absolute target path for saving edr files such as logs and reports",
+        )(func)
         func = click.option(
             "--disable-samples",
             type=bool,
@@ -154,10 +159,12 @@ def get_cli_properties() -> dict:
         return dict()
 
     reload_monitoring_configuration = params.get("reload_monitoring_configuration")
+    target_path = params.get("target_path")
     update_dbt_package = params.get("update_dbt_package")
     full_refresh_dbt_package = params.get("full_refresh_dbt_package")
 
     return {
+        "target_path": target_path,
         "reload_monitoring_configuration": reload_monitoring_configuration,
         "update_dbt_package": update_dbt_package,
         "full_refresh_dbt_package": full_refresh_dbt_package,
@@ -236,6 +243,7 @@ def monitor(
     env,
     select,
     group_by,
+    target_path,
 ):
     """
     Get alerts on failures in dbt jobs.
@@ -256,6 +264,7 @@ def monitor(
         project_dir,
         profile_target,
         project_profile_target,
+        target_path,
         dbt_quoting=dbt_quoting,
         slack_webhook=slack_webhook,
         slack_token=slack_token,
@@ -264,7 +273,7 @@ def monitor(
         env=env,
         slack_group_alerts_by=group_by,
     )
-    anonymous_tracking = AnonymousTracking(config)
+    anonymous_tracking = AnonymousCommandLineTracking(config)
     anonymous_tracking.set_env("use_select", bool(select))
     anonymous_tracking.track_cli_start(
         Command.MONITOR, get_cli_properties(), ctx.command.name
@@ -338,6 +347,7 @@ def report(
     project_name,
     env,
     select,
+    target_path,
 ):
     """
     Generate a local observability report of your warehouse.
@@ -348,10 +358,11 @@ def report(
         project_dir,
         profile_target,
         project_profile_target,
+        target_path,
         dbt_quoting=dbt_quoting,
         env=env,
     )
-    anonymous_tracking = AnonymousTracking(config)
+    anonymous_tracking = AnonymousCommandLineTracking(config)
     anonymous_tracking.set_env("use_select", bool(select))
     anonymous_tracking.track_cli_start(
         Command.REPORT, get_cli_properties(), ctx.command.name
@@ -471,7 +482,7 @@ def report(
     "--disable",
     type=str,
     default=None,
-    help='Disable functualities from the "send-report" command.\nCurrently only --disable html_attachment is supported.',
+    help='Disable functionalities from the "send-report" command.\nCurrently only --disable html_attachment is supported.',
 )
 @click.option(
     "--include",
@@ -513,6 +524,7 @@ def send_report(
     select,
     disable,
     include,
+    target_path,
 ):
     """
     Generate and send the report to an external platform.
@@ -525,6 +537,7 @@ def send_report(
         project_dir,
         profile_target,
         project_profile_target,
+        target_path,
         dbt_quoting=dbt_quoting,
         slack_token=slack_token,
         slack_channel_name=slack_channel_name,
@@ -540,7 +553,7 @@ def send_report(
         slack_report_url=slack_report_url,
         env=env,
     )
-    anonymous_tracking = AnonymousTracking(config)
+    anonymous_tracking = AnonymousCommandLineTracking(config)
     anonymous_tracking.set_env("use_select", bool(select))
     anonymous_tracking.track_cli_start(
         Command.SEND_REPORT, get_cli_properties(), ctx.command.name
@@ -588,5 +601,26 @@ def send_report(
         raise
 
 
+@monitor.command()
+@click.option(
+    "--profiles-dir",
+    "-p",
+    type=click.Path(exists=True),
+    default=None,
+    help="Which directory to look in for the profiles.yml file. "
+    "If not set, edr will look in the current working directory first, then HOME/.dbt/",
+)
+@click.pass_context
+def debug(ctx, profiles_dir):
+    config = Config(profiles_dir=profiles_dir)
+    anonymous_tracking = AnonymousCommandLineTracking(config)
+    anonymous_tracking.track_cli_start(Command.DEBUG, None, ctx.command.name)
+    success = Debug(config).run()
+    if not success:
+        sys.exit(1)
+
+    anonymous_tracking.track_cli_end(Command.DEBUG, None, ctx.command.name)
+
+
 if __name__ == "__main__":
     monitor()
