@@ -8,7 +8,7 @@ from elementary.clients.slack.client import SlackClient
 from elementary.config.config import Config
 from elementary.monitor import dbt_project_utils
 from elementary.monitor.data_monitoring.selector_filter import SelectorFilter
-from elementary.tracking.anonymous_tracking import AnonymousTracking
+from elementary.tracking.tracking_interface import Tracking
 from elementary.utils import package
 from elementary.utils.log import get_logger
 
@@ -22,28 +22,16 @@ class DataMonitoring:
     def __init__(
         self,
         config: Config,
-        tracking: AnonymousTracking,
+        tracking: Optional[Tracking] = None,
         force_update_dbt_package: bool = False,
         disable_samples: bool = False,
         filter: Optional[str] = None,
     ):
         self.config = config
         self.tracking = tracking
-        self.internal_dbt_runner = DbtRunner(
-            dbt_project_utils.PATH,
-            self.config.profiles_dir,
-            self.config.profile_target,
-            dbt_env_vars=self.config.dbt_env_vars,
-        )
-        if self.config.project_dir:
-            self.user_dbt_runner = DbtRunner(
-                self.config.project_dir,
-                self.config.profiles_dir,
-                self.config.project_profile_target,
-                dbt_env_vars=self.config.dbt_env_vars,
-            )
-        else:
-            self.user_dbt_runner = None
+        self.internal_dbt_runner = self._init_internal_dbt_runner()
+        self.user_dbt_runner = self._init_user_dbt_runner()
+
         self.execution_properties = {}
         latest_invocation = self.get_latest_invocation()
         self.project_name = latest_invocation.get("project_name")
@@ -69,6 +57,27 @@ class DataMonitoring:
             selector=self.raw_filter,
         )
 
+    def _init_internal_dbt_runner(self):
+        internal_dbt_runner = DbtRunner(
+            dbt_project_utils.PATH,
+            self.config.profiles_dir,
+            self.config.profile_target,
+            dbt_env_vars=self.config.dbt_env_vars,
+        )
+        return internal_dbt_runner
+
+    def _init_user_dbt_runner(self):
+        if self.config.project_dir:
+            user_dbt_runner = DbtRunner(
+                self.config.project_dir,
+                self.config.profiles_dir,
+                self.config.project_profile_target,
+                dbt_env_vars=self.config.dbt_env_vars,
+            )
+        else:
+            user_dbt_runner = None
+        return user_dbt_runner
+
     def _download_dbt_package_if_needed(self, force_update_dbt_packages: bool):
         internal_dbt_package_up_to_date = dbt_project_utils.is_dbt_package_up_to_date()
         self.execution_properties[
@@ -99,7 +108,7 @@ class DataMonitoring:
             )[0]
         except Exception as ex:
             logger.error("Failed to parse Elementary's database and schema.")
-            self.tracking.record_cli_internal_exception(ex)
+            self.tracking.record_internal_exception(ex)
             return "<elementary_database>.<elementary_schema>"
 
     def get_latest_invocation(self) -> Dict[str, Any]:
@@ -110,7 +119,7 @@ class DataMonitoring:
             return json.loads(latest_invocation)[0] if latest_invocation else {}
         except Exception as err:
             logger.error(f"Unable to get the latest invocation: {err}")
-            self.tracking.record_cli_internal_exception(err)
+            self.tracking.record_internal_exception(err)
             return {}
 
     @staticmethod
