@@ -16,7 +16,7 @@ from elementary.monitor.data_monitoring.data_monitoring import DataMonitoring
 from elementary.monitor.data_monitoring.report.slack_report_summary_message_builder import (
     SlackReportSummaryMessageBuilder,
 )
-from elementary.tracking.anonymous_tracking import AnonymousTracking
+from elementary.tracking.tracking_interface import Tracking
 from elementary.utils.log import get_logger
 
 logger = get_logger(__name__)
@@ -29,7 +29,7 @@ class DataMonitoringReport(DataMonitoring):
     def __init__(
         self,
         config: Config,
-        tracking: AnonymousTracking,
+        tracking: Tracking,
         filter: Optional[str] = None,
         force_update_dbt_package: bool = False,
         disable_samples: bool = False,
@@ -121,7 +121,7 @@ class DataMonitoringReport(DataMonitoring):
         self, report_data: ReportDataSchema, error: Exception = None
     ):
         if error:
-            self.tracking.record_cli_internal_exception(error)
+            self.tracking.record_internal_exception(error)
             return
 
         test_metadatas = []
@@ -177,17 +177,20 @@ class DataMonitoringReport(DataMonitoring):
             return self.success
 
         bucket_website_url = None
-        # If we upload the report to a bucket, we don't want to share it via Slack.
-        should_send_report_over_slack = not (
-            disable_html_attachment or self.s3_client or self.gcs_client
-        )
-
+        upload_succeeded = False
         # If a s3 client or a gcs client is provided, we want to upload the report to the bucket.
         if self.s3_client or self.gcs_client:
             upload_succeeded, bucket_website_url = self.upload_report(
                 local_html_path=local_html_path, remote_file_path=remote_file_path
             )
 
+        should_send_report_over_slack = True
+        # If we upload the report to a bucket, we don't want to share it via Slack.
+        if (
+            upload_succeeded and bucket_website_url is not None
+        ) or disable_html_attachment:
+            should_send_report_over_slack = False
+
         # If a Slack client is provided, we want send a results summary and attachment of the report if needed.
         if self.slack_client:
             # Send test results summary
