@@ -26,11 +26,5 @@
         {{ return(result_rows) }}
     {% endif %}
 
-    {% set query %}
-      with test_results as (
-        {{ test_query }}
-      )
-      select * from test_results {% if should_limit_sample %} limit {{ results_sample_limit }} {% endif %}
-    {% endset %}
-    {% do return(elementary.agate_to_dicts(elementary.run_query(query))) %}
+    {% do return([]) %}
 {%- endmacro -%}
