@@ -5,7 +5,7 @@ BUCKET_PATH_SEP = "/"
 
 def dirname(bucket_path: str) -> Optional[str]:
     dir_path = BUCKET_PATH_SEP.join(bucket_path.split(BUCKET_PATH_SEP)[:-1])
-    return dir_path if dir_path else None
+    return dir_path or None
 
 
 def basename(bucket_path: str) -> str:
