@@ -3,12 +3,8 @@ from typing import Optional
 import pkg_resources
 import requests
 
-from elementary.utils.log import get_logger
-
 _PYPI_URL = "https://pypi.org/pypi/elementary-data/json"
 
-logger = get_logger(__name__)
-
 
 def get_package_version() -> Optional[str]:
     try:
