@@ -6,8 +6,9 @@ from elementary.monitor.api.alerts.alert_filters import (
     _filter_alerts_by_node_names,
     _filter_alerts_by_owner,
     _filter_alerts_by_tag,
+    filter_alerts,
 )
-from elementary.monitor.data_monitoring.schema import DataMonitoringAlertsFilter
+from elementary.monitor.data_monitoring.schema import SelectorFilterSchema
 
 
 def initial_alerts():
@@ -137,10 +138,40 @@ def initial_alerts():
     return test_alerts, model_alerts, malformed_alerts
 
 
+def test_filter_alerts():
+    test_alerts, model_alerts, malformed_alerts = initial_alerts()
+
+    # Test that empty filter returns all of the alerts.
+    filter = SelectorFilterSchema()
+    filter_test_alerts = filter_alerts(test_alerts, filter)
+    filter_model_alerts = filter_alerts(model_alerts, filter)
+    filter_malformed_alerts = filter_alerts(malformed_alerts, filter)
+    assert len(filter_test_alerts) == len(test_alerts)
+    assert len(filter_model_alerts) == len(model_alerts)
+    assert len(filter_malformed_alerts) == len(malformed_alerts)
+
+    # Test that passing no filter returns all of the alerts.
+    filter_test_alerts = filter_alerts(test_alerts)
+    filter_model_alerts = filter_alerts(model_alerts)
+    filter_malformed_alerts = filter_alerts(malformed_alerts)
+    assert len(filter_test_alerts) == len(test_alerts)
+    assert len(filter_model_alerts) == len(model_alerts)
+    assert len(filter_malformed_alerts) == len(malformed_alerts)
+
+    # Test that filter with unsupported selector returns no alert
+    filter = SelectorFilterSchema(last_invocation=True, selector="last_invocation")
+    filter_test_alerts = filter_alerts(test_alerts, filter)
+    filter_model_alerts = filter_alerts(model_alerts, filter)
+    filter_malformed_alerts = filter_alerts(malformed_alerts, filter)
+    assert len(filter_test_alerts) == 0
+    assert len(filter_model_alerts) == 0
+    assert len(filter_malformed_alerts) == 0
+
+
 def test_filter_alerts_by_tag():
     test_alerts, model_alerts, malformed_alerts = initial_alerts()
 
-    filter = DataMonitoringAlertsFilter(tag="one")
+    filter = SelectorFilterSchema(tag="one")
     filter_test_alerts = _filter_alerts_by_tag(test_alerts, filter)
     filter_model_alerts = _filter_alerts_by_tag(model_alerts, filter)
     filter_malformed_alerts = _filter_alerts_by_tag(malformed_alerts, filter)
@@ -151,7 +182,7 @@ def test_filter_alerts_by_tag():
     assert len(filter_malformed_alerts) == 1
     assert filter_malformed_alerts[0].id == "1"
 
-    filter = DataMonitoringAlertsFilter(tag="three")
+    filter = SelectorFilterSchema(tag="three")
     filter_test_alerts = _filter_alerts_by_tag(test_alerts, filter)
     filter_model_alerts = _filter_alerts_by_tag(model_alerts, filter)
     filter_malformed_alerts = _filter_alerts_by_tag(malformed_alerts, filter)
@@ -164,7 +195,7 @@ def test_filter_alerts_by_tag():
     assert len(filter_malformed_alerts) == 1
     assert filter_malformed_alerts[0].id == "2"
 
-    filter = DataMonitoringAlertsFilter(tag="four")
+    filter = SelectorFilterSchema(tag="four")
     filter_test_alerts = _filter_alerts_by_tag(test_alerts, filter)
     filter_model_alerts = _filter_alerts_by_tag(model_alerts, filter)
     filter_malformed_alerts = _filter_alerts_by_tag(malformed_alerts, filter)
@@ -178,7 +209,7 @@ def test_filter_alerts_by_tag():
 def test_filter_alerts_by_owner():
     test_alerts, model_alerts, malformed_alerts = initial_alerts()
 
-    filter = DataMonitoringAlertsFilter(owner="jeff")
+    filter = SelectorFilterSchema(owner="jeff")
     filter_test_alerts = _filter_alerts_by_owner(test_alerts, filter)
     filter_model_alerts = _filter_alerts_by_owner(model_alerts, filter)
     filter_malformed_alerts = _filter_alerts_by_owner(malformed_alerts, filter)
@@ -192,7 +223,7 @@ def test_filter_alerts_by_owner():
     assert len(filter_malformed_alerts) == 1
     assert filter_malformed_alerts[0].id == "1"
 
-    filter = DataMonitoringAlertsFilter(owner="john")
+    filter = SelectorFilterSchema(owner="john")
     filter_test_alerts = _filter_alerts_by_owner(test_alerts, filter)
     filter_model_alerts = _filter_alerts_by_owner(model_alerts, filter)
     filter_malformed_alerts = _filter_alerts_by_owner(malformed_alerts, filter)
@@ -211,7 +242,7 @@ def test_filter_alerts_by_owner():
 def test_filter_alerts_by_model():
     test_alerts, model_alerts, malformed_alerts = initial_alerts()
 
-    filter = DataMonitoringAlertsFilter(model="model_id_1")
+    filter = SelectorFilterSchema(model="model_id_1")
     filter_test_alerts = _filter_alerts_by_model(test_alerts, filter)
     filter_model_alerts = _filter_alerts_by_model(model_alerts, filter)
     filter_malformed_alerts = _filter_alerts_by_model(malformed_alerts, filter)
@@ -225,7 +256,7 @@ def test_filter_alerts_by_model():
     assert filter_malformed_alerts[0].id == "1"
     assert filter_malformed_alerts[1].id == "2"
 
-    filter = DataMonitoringAlertsFilter(model="model_id_2")
+    filter = SelectorFilterSchema(model="model_id_2")
     filter_test_alerts = _filter_alerts_by_model(test_alerts, filter)
     filter_model_alerts = _filter_alerts_by_model(model_alerts, filter)
     filter_malformed_alerts = _filter_alerts_by_model(malformed_alerts, filter)
@@ -240,7 +271,7 @@ def test_filter_alerts_by_model():
 def test_filter_alerts_by_node_names():
     test_alerts, model_alerts, malformed_alerts = initial_alerts()
 
-    filter = DataMonitoringAlertsFilter(node_names=["test_3", "model_id_1"])
+    filter = SelectorFilterSchema(node_names=["test_3", "model_id_1"])
     filter_test_alerts = _filter_alerts_by_node_names(test_alerts, filter)
     filter_model_alerts = _filter_alerts_by_node_names(model_alerts, filter)
     filter_malformed_alerts = _filter_alerts_by_node_names(malformed_alerts, filter)
@@ -252,7 +283,7 @@ def test_filter_alerts_by_node_names():
     assert len(filter_malformed_alerts) == 1
     assert filter_malformed_alerts[0].id == "2"
 
-    filter = DataMonitoringAlertsFilter(node_names=["model_id_2"])
+    filter = SelectorFilterSchema(node_names=["model_id_2"])
     filter_test_alerts = _filter_alerts_by_node_names(test_alerts, filter)
     filter_model_alerts = _filter_alerts_by_node_names(model_alerts, filter)
     filter_malformed_alerts = _filter_alerts_by_node_names(malformed_alerts, filter)
@@ -261,7 +292,7 @@ def test_filter_alerts_by_node_names():
     assert filter_model_alerts[0].id == "3"
     assert len(filter_malformed_alerts) == 0
 
-    filter = DataMonitoringAlertsFilter(node_names=["model_id_3"])
+    filter = SelectorFilterSchema(node_names=["model_id_3"])
     filter_malformed_alerts = _filter_alerts_by_node_names(malformed_alerts, filter)
     filter_test_alerts = _filter_alerts_by_node_names(test_alerts, filter)
     filter_model_alerts = _filter_alerts_by_node_names(model_alerts, filter)
@@ -269,7 +300,7 @@ def test_filter_alerts_by_node_names():
     assert len(filter_model_alerts) == 0
     assert len(filter_malformed_alerts) == 0
 
-    filter = DataMonitoringAlertsFilter(node_names=["test_1"])
+    filter = SelectorFilterSchema(node_names=["test_1"])
     filter_malformed_alerts = _filter_alerts_by_node_names(malformed_alerts, filter)
     assert len(filter_malformed_alerts) == 1
     assert filter_malformed_alerts[0].id == "1"
